@@ -2,10 +2,12 @@
 # -*- coding: utf-8 -*-
 from django import forms
 from django.utils.safestring import mark_safe
-from paypal.standard.conf import *
 from paypal.standard.widgets import ValueHiddenInput, ReservedValueHiddenInput
 from paypal.standard.conf import (POSTBACK_ENDPOINT, SANDBOX_POSTBACK_ENDPOINT,
-                                  RECEIVER_EMAIL)
+                                  RECEIVER_EMAIL,
+                                  IMAGE, SUBSCRIPTION_IMAGE, DONATION_IMAGE,
+                                  SANDBOX_IMAGE, SUBSCRIPTION_SANDBOX_IMAGE, DONATION_SANDBOX_IMAGE)
+from django.conf import settings
 
 
 # 20:18:05 Jan 30, 2009 PST - PST timezone support is not included out of the box.
@@ -33,6 +35,7 @@ class PayPalPaymentsForm(forms.Form):
     """
     CMD_CHOICES = (
         ("_xclick", "Buy now or Donations"),
+        ("_donations", "Donations"),
         ("_cart", "Shopping cart"),
         ("_xclick-subscriptions", "Subscribe")
     )
@@ -98,19 +101,36 @@ class PayPalPaymentsForm(forms.Form):
     def __init__(self, button_type="buy", *args, **kwargs):
         super(PayPalPaymentsForm, self).__init__(*args, **kwargs)
         self.button_type = button_type
+        if 'initial' in kwargs:
+            # Dynamically create, so we can support everything PayPal does.
+            for k, v in kwargs['initial'].items():
+                if k not in self.base_fields:
+                    self.fields[k] = forms.CharField(label=k, widget=ValueHiddenInput(), initial=v)
+
+    def test_mode(self):
+        return getattr(settings, 'PAYPAL_TEST', True)
+
+    def get_endpoint(self):
+        "Returns the endpoint url for the form."
+        if self.test_mode():
+            return SANDBOX_POSTBACK_ENDPOINT
+        else:
+            return POSTBACK_ENDPOINT
+
 
     def render(self):
         return mark_safe(u"""<form action="%s" method="post">
     %s
     <input type="image" src="%s" border="0" name="submit" alt="Buy it Now" />
-</form>""" % (POSTBACK_ENDPOINT, self.as_p(), self.get_image()))
+</form>""" % (self.get_endpoint(), self.as_p(), self.get_image()))
 
 
     def sandbox(self):
-        return mark_safe(u"""<form action="%s" method="post">
-    %s
-    <input type="image" src="%s" border="0" name="submit" alt="Buy it Now" />
-</form>""" % (SANDBOX_POSTBACK_ENDPOINT, self.as_p(), self.get_image()))
+        "Deprecated.  Use self.render() instead."
+        import warnings
+        warnings.warn("""PaypalPaymentsForm.sandbox() is deprecated.
+                    Use the render() method instead.""", DeprecationWarning)
+        return self.render()
 
     def get_image(self):
         return {
@@ -120,7 +140,7 @@ class PayPalPaymentsForm(forms.Form):
             (False, self.SUBSCRIBE): SUBSCRIPTION_IMAGE,
             (False, self.BUY): IMAGE,
             (False, self.DONATE): DONATION_IMAGE,
-        }[TEST, self.button_type]
+        }[self.test_mode(), self.button_type]
 
     def is_transaction(self):
         return not self.is_subscription()
@@ -153,7 +173,7 @@ class PayPalEncryptedPaymentsForm(PayPalPaymentsForm):
 
         # Iterate through the fields and pull out the ones that have a value.
         plaintext = 'cert_id=%s\n' % CERT_ID
-        for name, field in self.fields.iteritems():
+        for name, field in self.fields.items():
             value = None
             if name in self.initial:
                 value = self.initial[name]
