@@ -1,6 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django.db import models
+from django.utils.functional import cached_property
+
 from paypal.standard.helpers import duplicate_txn_id, check_secret
 from paypal.standard.conf import RECEIVER_EMAIL, POSTBACK_ENDPOINT, SANDBOX_POSTBACK_ENDPOINT
 
@@ -157,6 +159,9 @@ class PayPalStandardBase(Model):
     subscr_id = models.CharField(max_length=19, blank=True)
     username = models.CharField(max_length=64, blank=True)
 
+    # Billing Agreement Variables
+    mp_id = models.CharField(max_length=128, blank=True, null=True) # B-0G433009BJ555711U
+
     # Dispute Resolution Variables
     case_creation_date = models.DateTimeField(blank=True, null=True, help_text="HH:MM:SS DD Mmm YY, YYYY PST")
     case_id = models.CharField(max_length=14, blank=True)
@@ -185,7 +190,7 @@ class PayPalStandardBase(Model):
     # unique_id_x = models.CharField(max_length=13, blank=True)
 
     # Non-PayPal Variables - full IPN/PDT query and time fields.
-    ipaddress = models.IPAddressField(blank=True)
+    ipaddress = models.GenericIPAddressField(blank=True, null=True)
     flag = models.BooleanField(default=False, blank=True)
     flag_code = models.CharField(max_length=16, blank=True)
     flag_info = models.TextField(blank=True)
@@ -206,6 +211,22 @@ class PayPalStandardBase(Model):
         else:
             return self.format % ("Recurring", self.recurring_payment_id)
 
+    @cached_property
+    def posted_data_dict(self):
+        """
+        All the data that PayPal posted to us, as a correctly parsed dictionary of values.
+        """
+        if not self.query:
+            return None
+        from django.http import QueryDict
+        roughdecode = dict(item.split('=', 1) for item in self.query.split('&'))
+        encoding = roughdecode.get('charset', None)
+        if encoding is None:
+            return None
+        query = self.query.encode('ascii')
+        data = QueryDict(query, encoding=encoding)
+        return data.dict()
+
     def is_transaction(self):
         return len(self.txn_id) > 0
 
@@ -245,6 +266,15 @@ class PayPalStandardBase(Model):
     def is_recurring_failed(self):
         return self.txn_type == "recurring_payment_failed"
 
+    def is_billing_agreement(self):
+        return len(self.mp_id) > 0
+
+    def is_billing_agreement_create(self):
+        return self.txn_type == "mp_signup"
+
+    def is_billing_agreement_cancel(self):
+        return self.txn_type == "mp_cancel"
+
     def set_flag(self, info, code=None):
         """Sets a flag on the transaction and also sets a reason."""
         self.flag = True
@@ -263,7 +293,7 @@ class PayPalStandardBase(Model):
         that `mc_gross`, `mc_currency` `item_name` and `item_number` are all correct.
 
         """
-        self.response = self._postback()
+        self.response = self._postback().decode('ascii')
         self._verify_postback()
         if not self.flag:
             if self.is_transaction():
@@ -282,14 +312,12 @@ class PayPalStandardBase(Model):
                 pass
 
         self.save()
-        self.send_signals()
 
     def verify_secret(self, form_instance, secret):
         """Verifies an IPN payment over SSL using EWP."""
         if not check_secret(form_instance, secret):
             self.set_flag("Invalid secret. (%s)") % secret
         self.save()
-        self.send_signals()
 
     def get_endpoint(self):
         """Set Sandbox endpoint if the test variable is present."""
@@ -300,27 +328,7 @@ class PayPalStandardBase(Model):
 
     def send_signals(self):
         """Shout for the world to hear whether a txn was successful."""
-
-        # Don't do anything if we're not notifying!
-        if self.from_view != 'notify':
-            return
-
-        # Transaction signals:
-        if self.is_transaction():
-            if self.flag:
-                payment_was_flagged.send(sender=self)
-            else:
-                payment_was_successful.send(sender=self)
-        # Subscription signals:
-        else:
-            if self.is_subscription_cancellation():
-                subscription_cancel.send(sender=self)
-            elif self.is_subscription_signup():
-                subscription_signup.send(sender=self)
-            elif self.is_subscription_end_of_term():
-                subscription_eot.send(sender=self)
-            elif self.is_subscription_modified():
-                subscription_modify.send(sender=self)
+        raise NotImplementedError
 
     def initialize(self, request):
         """Store the data we'll need to make the postback from the request object."""
@@ -329,7 +337,7 @@ class PayPalStandardBase(Model):
             self.query = request.META.get('QUERY_STRING', '')
         elif request.method == 'POST':
             # The following works if paypal sends an ASCII bytestring, which it does.
-            self.query = request.body
+            self.query = request.body.decode('ascii')
         self.ipaddress = request.META.get('REMOTE_ADDR', '')
 
     def _postback(self):
