@@ -1,9 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 from django import forms
-from django.forms.util import flatatt
+try:
+    from django.forms.utils import flatatt # Django 1.7 and later
+except ImportError:
+    from django.forms.util import flatatt # earlier
+
 from django.utils.safestring import mark_safe
-from django.utils.encoding import force_unicode
+from django.utils.encoding import force_text
 
 
 class ValueHiddenInput(forms.HiddenInput):
@@ -30,5 +34,5 @@ class ReservedValueHiddenInput(ValueHiddenInput):
             value = ''
         final_attrs = self.build_attrs(attrs, type=self.input_type)
         if value != '':
-            final_attrs['value'] = force_unicode(value)
-        return mark_safe(u'<input%s />' % flatatt(final_attrs))
\ No newline at end of file
+            final_attrs['value'] = force_text(value)
+        return mark_safe(u'<input%s />' % flatatt(final_attrs))
